#ifndef SAVECORE_H
#define SAVECORE_H

#include "version.h"
#include "diskdumpelf.h"
#include "dumpdevice.h"
#include "diskdumpcmn.h"

/* Save dump into "/var/crash/127.0.0.1-<date-time>/vmcore[-incomplete]" */
#define DISKDUMP_DIR_PREFIX	"/var/crash/"
#define DISKDUMP_IP		0x7f000001

#define DATE_TIME_FORMAT	"YYYY-mm-dd-HH:MM"

#define COMPLETE_DUMP_FILE	"vmcore"
#define INCOMPLETE_DUMP_FILE	COMPLETE_DUMP_FILE"-incomplete"	/* default */

/* Available only once when there are not enough space to dump memory */
#define DISKDUMP_NOSPACE	DISKDUMP_DIR_PREFIX"scripts/diskdump-nospace"

/* The minimum size of memory hole which causes splitting segments */
#define HOLE_SIZE	256

/* Utility macros */
#define roundup(x, y)	((((x) + ((y) - 1)) / (y)) * (y))
#define divideup(x, y)	(((x) + ((y) - 1)) / (y))


/* Error code for read_device_header() and write_pages() */
enum {
	COMPLETE,			/* 0 (not an error) */
	BLOCK_SIZE_INVALID,
	SEEK_ERROR_IN_DUMP_HEADER,
	READ_ERROR_IN_DUMP_HEADER,
	SEEK_ERROR_IN_DUMP_SUB_HEADER,
	READ_ERROR_IN_DUMP_SUB_HEADER,
	SEEK_ERROR_IN_MEMORY_BITMAP,
	READ_ERROR_IN_MEMORY_BITMAP,
	NO_PANIC_DUMP_HEADER,
	SIZE_NOT_MATCH,
	NUMBER_OF_CPUS_INVALID,
	SEEK_ERROR_IN_DUMP_DEVICE,
	READ_ERROR_IN_DUMP_DEVICE,
	SEEK_ERROR_IN_DUMP_FILE,
	WRITE_ERROR_IN_DUMP_FILE,
	DUMP_FILE_SIZE_UNDETERMINED
};

static inline int dump_is_partial(const struct disk_dump_header *header)
{
	return header->bitmap_blocks >=
	    divideup(divideup(header->max_mapnr, 8), header->block_size) * 2;
}

#endif
